@@ -157,7 +157,7 @@ End Sub'''
 
 
 class Script:
-    def __init__(name, route_geometry, route_cst):
+    def __init__(self, name, route_geometry, route_cst):
         self.create_script(name, route_geometry, route_cst)
 
     @staticmethod
@@ -166,9 +166,12 @@ class Script:
         path_to_cst_file = os.path.abspath(f"{route_cst}\{name}.cst")
         source = _script_source.format(path_to_geometry, path_to_cst_file)
 
-        with open(os.path.abspath('script.bas'), 'w') as f:
-            f.writelines(source.split('\n'))
+        with open(os.path.abspath('script.bas'), 'w+') as f:
+            for line in source.split('\n'):
+                f.write(f'{line}\n')
+            print(f'script added at {os.path.abspath("script.bas")}')
 
     @staticmethod
     def remove_script():
-        os.remove(os.path.abspath('script.bas'))
+        os.remove(os.path.abspath('script.bas')); print(f'script removed from {os.path.abspath("script.bas")}')
+
