@@ -1,5 +1,5 @@
 import os
-from cst_geometry import Script
+from ._script import Script
 
 
 class Wire:
@@ -40,8 +40,8 @@ class Geometry:
 
         script = Script(name=name, route_geometry=path_to_geometry_folder, route_cst=path_to_CST_project)
 
-        path_to_script = os.path.abspath('script.bas')
+        path_to_script = os.path.abspath('script.bas'); print(f'"{path_to_CST_DE}" -m "{path_to_script}"')
         stream = os.popen(f'"{path_to_CST_DE}" -m "{path_to_script}"')
-        script.remove_script()
+        #script.remove_script()
         return stream.read()
 
